Usage
=====

.. toctree::
   :maxdepth: 0
   :caption: Tutorials:

   Basic usage <tutorials/example_exponential>
   More complex usage on a 2D diffusion example <tutorials/example_exponential>
   Correlation matrices building <tutorials/correlation_matrices_building>

* :ref:`genindex`
